package VMOMI::DvsEventPortBlockState;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
